==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/ClusterControlUI/src/com/clustercontrol/calendar/view/action/AddInfoAddAction.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.calendar.view.action;

import org.eclipse.jface.action.IAction;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.ui.IViewActionDelegate;
import org.eclipse.ui.IViewPart;

import com.clustercontrol.bean.PropertyConstant;
import com.clustercontrol.calendar.dialog.AddInfoDialog;
import com.clustercontrol.calendar.view.AddInfoListView;

/**
 * ɲþκѹˤ롢ɲþϿԤ󥯥饹Ǥ
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class AddInfoAddAction implements IViewActionDelegate {
	public static final String ID = "com.clustercontrol.calendar.view.action.AddInfoAddAction";
	
    private IViewPart viewPart;

    /**
     * @see org.eclipse.ui.IViewActionDelegate#init(org.eclipse.ui.IViewPart)
     */
    public void init(IViewPart viewPart) {
        this.viewPart = viewPart;
    }

    /**
     * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
     */
    public void run(IAction action) {
    	//ID
        AddInfoListView view = 
        	(AddInfoListView)this.viewPart.getAdapter(AddInfoListView.class);
        String calendarId = view.getComposite().getCalendarId();
        
        if(calendarId != null & calendarId.length() > 0){
	        // 
	        AddInfoDialog dialog = 
	        	new AddInfoDialog(this.viewPart.getSite().getShell(), calendarId, null, null, PropertyConstant.MODE_ADD);
	
	        // ˤѹ򤵤줿硢ƤäϿԤ
	        dialog.open();
	        
	        view.update(calendarId);
    	}
    }

    /**
     * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction,
     *      org.eclipse.jface.viewers.ISelection)
     */
    public void selectionChanged(IAction action, ISelection selection) {
    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/ClusterControlUI/src/com/clustercontrol/calendar/view/action/AddInfoAddAction.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.calendar.view.action;

import org.eclipse.jface.action.IAction;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.ui.IViewActionDelegate;
import org.eclipse.ui.IViewPart;

import com.clustercontrol.bean.PropertyConstant;
import com.clustercontrol.calendar.dialog.AddInfoDialog;
import com.clustercontrol.calendar.view.AddInfoListView;

/**
 * カレンダ追加情報の作成・変更ダイアログによる、カレンダ追加情報の登録を行うアクションクラスです。
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class AddInfoAddAction implements IViewActionDelegate {
	public static final String ID = "com.clustercontrol.calendar.view.action.AddInfoAddAction";
	
    private IViewPart viewPart;

    /**
     * @see org.eclipse.ui.IViewActionDelegate#init(org.eclipse.ui.IViewPart)
     */
    public void init(IViewPart viewPart) {
        this.viewPart = viewPart;
    }

    /**
     * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
     */
    public void run(IAction action) {
    	//カレンダIDを取得
        AddInfoListView view = 
        	(AddInfoListView)this.viewPart.getAdapter(AddInfoListView.class);
        String calendarId = view.getComposite().getCalendarId();
        
        if(calendarId != null & calendarId.length() > 0){
	        // ダイアログを生成
	        AddInfoDialog dialog = 
	        	new AddInfoDialog(this.viewPart.getSite().getShell(), calendarId, null, null, PropertyConstant.MODE_ADD);
	
	        // ダイアログにて変更が選択された場合、入力内容をもって登録を行う。
	        dialog.open();
	        
	        view.update(calendarId);
    	}
    }

    /**
     * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction,
     *      org.eclipse.jface.viewers.ISelection)
     */
    public void selectionChanged(IAction action, ISelection selection) {
    }
}
